==> nomachine-8.13.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXPingManager.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2024 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package NXPingManager;no warnings;(my $__pingRequestTime=(0x1448+ 2168-0x1cc0));
(my $__pingTime=(0x08a0+ 716-0x0b6c));(my $__interval=(0x17a5+ 2539-0x2190));(my $__timeout
=(0x0b40+ 1240-0x1018));(my $__errorTimeout=(0x0047+ 805-0x036c));sub initialize
{__setTimeBetweenPingsFromNode ();__setTimeoutForPingAfterRequest ();
__setPingRequestTime ();}sub __setTimeBetweenPingsFromNode{($__interval=
(0x11b1+ 1239-0x163d));Logger::debug (((
"\x4e\x58\x50\x69\x6e\x67\x4d\x61\x6e\x61\x67\x65\x72\x3a\x20\x54\x69\x6d\x65\x20\x62\x65\x74\x77\x65\x65\x6e\x20\x70\x69\x6e\x67\x73\x20\x66\x72\x6f\x6d\x20\x74\x68\x65\x20\x6e\x6f\x64\x65\x3a\x20"
.$__interval)."\x2e"));}sub __setTimeoutForPingAfterRequest{($__timeout=
NXNodeConfiguration::getNodeConnectionTimeout ());Logger::debug (((
"\x4e\x58\x50\x69\x6e\x67\x4d\x61\x6e\x61\x67\x65\x72\x3a\x20\x54\x69\x6d\x65\x6f\x75\x74\x20\x66\x6f\x72\x20\x70\x69\x6e\x67\x20\x61\x66\x74\x65\x72\x20\x72\x65\x71\x75\x65\x73\x74\x3a\x20"
.$__timeout)."\x2e"));}sub checkTimesAndRequestPingIfNecessary{if ((
__isPingEnabled ()==(0x1d04+ 1273-0x21fd))){return;}if ((__isTimeout ()==
(0x10e5+ 1798-0x17ea))){if ((__isErrorTimeout ()==(0x0449+ 4138-0x1472))){(my $msg
=((
"\x4e\x6f\x64\x65\x20\x64\x69\x64\x20\x6e\x6f\x74\x20\x70\x69\x6e\x67\x20\x73\x69\x6e\x63\x65\x20"
.$__timeout).
"\x20\x73\x65\x63\x6f\x6e\x64\x73\x2e\x20\x54\x65\x72\x6d\x69\x6e\x61\x74\x69\x6e\x67\x20\x73\x65\x73\x73\x69\x6f\x6e\x2e"
));Logger::error ($msg);Logger::statusPushError ($msg);die ($msg);}
__setErrorTimeout ();Logger::warning (((
"\x4e\x6f\x64\x65\x20\x64\x69\x64\x20\x6e\x6f\x74\x20\x70\x69\x6e\x67\x20\x73\x69\x6e\x63\x65\x20"
.$__timeout)."\x20\x73\x65\x63\x6f\x6e\x64\x73\x2e"));__sendPingRequest ();
return;}if ((__isPingRequestTime ()==(0x2367+ 675-0x2609))){__sendPingRequest ()
;return;}}sub handlePing{Logger::debug (
"\x52\x65\x63\x65\x69\x76\x65\x64\x20\x70\x69\x6e\x67\x20\x6d\x65\x73\x73\x61\x67\x65\x2e"
);__resetPingRequestTime ();__clearErrorTimeout ();Logger::debug (
"\x53\x65\x6e\x64\x69\x6e\x67\x20\x70\x6f\x6e\x67\x20\x6d\x65\x73\x73\x61\x67\x65\x2e"
);NXNodeExec::sendToNode ((((("\x4e\x58\x3e\x20".$GLOBAL::MSG_NODE_PONG)."\x20")
.$GLOBAL::MESSAGES_FORMAT{$GLOBAL::MSG_NODE_PONG})."\x0a"));__setPingTime ();}
sub __isPingRequestTime{if (($__pingTime==(0x090c+ 1419-0x0e97))){return (
(0x02ac+ 8552-0x2414));}(my $time=Common::NXTime::getSecondsSinceEpoch ());if ((
$time>=($__pingTime+$__interval))){return ((0x19ff+ 2450-0x2390));}return (
(0x012c+ 5166-0x155a));}sub __resetPingRequestTime{($__pingRequestTime=
(0x1732+ 1312-0x1c52));}sub __setPingRequestTime{($__pingRequestTime=
Common::NXTime::getSecondsSinceEpoch ());}sub __sendPingRequest{Logger::debug (
"\x53\x65\x6e\x64\x69\x6e\x67\x20\x72\x65\x71\x75\x65\x73\x74\x20\x70\x69\x6e\x67\x20\x6d\x65\x73\x73\x61\x67\x65\x2e"
);NXNodeExec::sendToNode ((((("\x4e\x58\x3e\x20".$GLOBAL::MSG_REQUEST_FOR_PING).
"\x20").$GLOBAL::MESSAGES_FORMAT{$GLOBAL::MSG_REQUEST_FOR_PING})."\x0a"));
__setPingRequestTime ();__resetPingTime ();}sub disable{($__timeout=
(0x0bdb+  50-0x0c0d));Logger::debug (
"\x4e\x58\x50\x69\x6e\x67\x4d\x61\x6e\x61\x67\x65\x72\x3a\x20\x44\x69\x73\x61\x62\x6c\x65\x20\x70\x69\x6e\x67\x20\x6d\x6f\x6e\x69\x74\x6f\x72\x2e"
);}sub __isPingEnabled{if (($__timeout==(0x0c3d+ 1359-0x118c))){return (
(0x04d6+ 2233-0x0d8f));}return ((0x108b+ 1093-0x14cf));}sub __isTimeout{if ((
$__pingRequestTime==(0x18e9+  22-0x18ff))){return ((0x1360+ 2431-0x1cdf));}(my $time
=Common::NXTime::getSecondsSinceEpoch ());if (($__pingRequestTime>$time)){(
$__pingRequestTime=Common::NXTime::getSecondsSinceEpoch ());}if (($time>=(
$__pingRequestTime+$__timeout))){return ((0x086f+ 7095-0x2425));}return (
(0x00a7+ 7497-0x1df0));}sub __setPingTime{($__pingTime=
Common::NXTime::getSecondsSinceEpoch ());}sub __resetPingTime{($__pingTime=
(0x07ac+ 4216-0x1824));}sub __setErrorTimeout{($__errorTimeout=
(0x0b6d+ 3420-0x18c8));}sub __isErrorTimeout{return ($__errorTimeout);}sub 
__clearErrorTimeout{($__errorTimeout=(0x0baf+ 897-0x0f30));}return (
(0x13f6+ 587-0x1640));

==> nomachine-8.14.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXPingManager.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2024 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package NXPingManager;no warnings;(my $__pingRequestTime=(0x05a2+ 6791-0x2029));
(my $__pingTime=(0x047a+ 5633-0x1a7b));(my $__interval=(0x00a3+  83-0x00f6));(my $__timeout
=(0x02a0+ 3058-0x0e92));(my $__errorTimeout=(0x1f8d+ 268-0x2099));sub initialize
{__setTimeBetweenPingsFromNode ();__setTimeoutForPingAfterRequest ();
__setPingRequestTime ();}sub __setTimeBetweenPingsFromNode{($__interval=
(0x0063+ 3483-0x0db3));Logger::debug (((
"\x4e\x58\x50\x69\x6e\x67\x4d\x61\x6e\x61\x67\x65\x72\x3a\x20\x54\x69\x6d\x65\x20\x62\x65\x74\x77\x65\x65\x6e\x20\x70\x69\x6e\x67\x73\x20\x66\x72\x6f\x6d\x20\x74\x68\x65\x20\x6e\x6f\x64\x65\x3a\x20"
.$__interval)."\x2e"));}sub __setTimeoutForPingAfterRequest{($__timeout=
NXNodeConfiguration::getNodeConnectionTimeout ());Logger::debug (((
"\x4e\x58\x50\x69\x6e\x67\x4d\x61\x6e\x61\x67\x65\x72\x3a\x20\x54\x69\x6d\x65\x6f\x75\x74\x20\x66\x6f\x72\x20\x70\x69\x6e\x67\x20\x61\x66\x74\x65\x72\x20\x72\x65\x71\x75\x65\x73\x74\x3a\x20"
.$__timeout)."\x2e"));}sub checkTimesAndRequestPingIfNecessary{if ((
__isPingEnabled ()==(0x0a89+ 4899-0x1dac))){return;}if ((__isTimeout ()==
(0x0a18+ 277-0x0b2c))){if ((__isErrorTimeout ()==(0x01bf+ 572-0x03fa))){(my $msg
=((
"\x4e\x6f\x64\x65\x20\x64\x69\x64\x20\x6e\x6f\x74\x20\x70\x69\x6e\x67\x20\x73\x69\x6e\x63\x65\x20"
.$__timeout).
"\x20\x73\x65\x63\x6f\x6e\x64\x73\x2e\x20\x54\x65\x72\x6d\x69\x6e\x61\x74\x69\x6e\x67\x20\x73\x65\x73\x73\x69\x6f\x6e\x2e"
));Logger::error ($msg);Logger::statusPushError ($msg);die ($msg);}
__setErrorTimeout ();Logger::warning (((
"\x4e\x6f\x64\x65\x20\x64\x69\x64\x20\x6e\x6f\x74\x20\x70\x69\x6e\x67\x20\x73\x69\x6e\x63\x65\x20"
.$__timeout)."\x20\x73\x65\x63\x6f\x6e\x64\x73\x2e"));__sendPingRequest ();
return;}if ((__isPingRequestTime ()==(0x132a+ 2698-0x1db3))){__sendPingRequest 
();return;}}sub handlePing{Logger::debug (
"\x52\x65\x63\x65\x69\x76\x65\x64\x20\x70\x69\x6e\x67\x20\x6d\x65\x73\x73\x61\x67\x65\x2e"
);__resetPingRequestTime ();__clearErrorTimeout ();Logger::debug (
"\x53\x65\x6e\x64\x69\x6e\x67\x20\x70\x6f\x6e\x67\x20\x6d\x65\x73\x73\x61\x67\x65\x2e"
);NXNodeExec::sendToNode ((((("\x4e\x58\x3e\x20".$GLOBAL::MSG_NODE_PONG)."\x20")
.$GLOBAL::MESSAGES_FORMAT{$GLOBAL::MSG_NODE_PONG})."\x0a"));__setPingTime ();}
sub __isPingRequestTime{if (($__pingTime==(0x0a93+ 3703-0x190a))){return (
(0x0def+ 5806-0x249d));}(my $time=Common::NXTime::getSecondsSinceEpoch ());if ((
$time>=($__pingTime+$__interval))){return ((0x105f+ 3856-0x1f6e));}return (
(0x09f8+ 3415-0x174f));}sub __resetPingRequestTime{($__pingRequestTime=
(0x02ad+ 1323-0x07d8));}sub __setPingRequestTime{($__pingRequestTime=
Common::NXTime::getSecondsSinceEpoch ());}sub __sendPingRequest{Logger::debug (
"\x53\x65\x6e\x64\x69\x6e\x67\x20\x72\x65\x71\x75\x65\x73\x74\x20\x70\x69\x6e\x67\x20\x6d\x65\x73\x73\x61\x67\x65\x2e"
);NXNodeExec::sendToNode ((((("\x4e\x58\x3e\x20".$GLOBAL::MSG_REQUEST_FOR_PING).
"\x20").$GLOBAL::MESSAGES_FORMAT{$GLOBAL::MSG_REQUEST_FOR_PING})."\x0a"));
__setPingRequestTime ();__resetPingTime ();}sub disable{($__timeout=
(0x1e19+ 1708-0x24c5));Logger::debug (
"\x4e\x58\x50\x69\x6e\x67\x4d\x61\x6e\x61\x67\x65\x72\x3a\x20\x44\x69\x73\x61\x62\x6c\x65\x20\x70\x69\x6e\x67\x20\x6d\x6f\x6e\x69\x74\x6f\x72\x2e"
);}sub __isPingEnabled{if (($__timeout==(0x24cb+ 298-0x25f5))){return (
(0x02ff+ 2977-0x0ea0));}return ((0x092f+ 1552-0x0f3e));}sub __isTimeout{if ((
$__pingRequestTime==(0x09e6+ 4068-0x19ca))){return ((0x1f37+ 1102-0x2385));}(my $time
=Common::NXTime::getSecondsSinceEpoch ());if (($__pingRequestTime>$time)){(
$__pingRequestTime=Common::NXTime::getSecondsSinceEpoch ());}if (($time>=(
$__pingRequestTime+$__timeout))){return ((0x0319+ 8707-0x251b));}return (
(0x00ec+ 2895-0x0c3b));}sub __setPingTime{($__pingTime=
Common::NXTime::getSecondsSinceEpoch ());}sub __resetPingTime{($__pingTime=
(0x0832+ 2041-0x102b));}sub __setErrorTimeout{($__errorTimeout=
(0x0b53+ 5721-0x21ab));}sub __isErrorTimeout{return ($__errorTimeout);}sub 
__clearErrorTimeout{($__errorTimeout=(0x0281+ 7668-0x2075));}return (
(0x05c5+ 7810-0x2446));
